import QtQuick 2.12
import org.kde.plasma.core 2.0 as PlasmaCore

import org.kde.plasma.networkmanagement 0.2 as PlasmaNM
import ru.astralinux.plasma.private.astraairplanemode 1.0
import ru.astralinux.plasma.private.astraswitchinerfeces 1.0

pragma Singleton

Item {
    id: root

    readonly property bool airplaneModeEnabled: AstraAirplaneModeConfig.enable

    function setAirplaneMode(inEnable) {
        if (root.airplaneModeEnabled === inEnable)
            return;

        PlasmaNM.Configuration.airplaneModeEnabled = inEnable;
        AstraAirplaneModeConfig.enable = inEnable;

        if (inEnable) {
            saveNetworkInterfacesStatus();
            disableInterfces();
        } else {
            restoreInterfaces();
            saveNetworkInterfacesStatus();
        }
    }

    function saveNetworkInterfacesStatus() {
        AstraAirplaneModeConfig.setCurrentBluetoothWasActive();
        AstraAirplaneModeConfig.setCurrentWifiWasActive();
        AstraAirplaneModeConfig.setCurrentMobileDataWasActive();
    }

    function disableInterfces() {
        AstraSwitchInerfeces.enableBluetooth(false);
        AstraSwitchInerfeces.enableWireless(false);
        AstraSwitchInerfeces.enableWwan(false);
    }

    function restoreInterfaces() {
        if (AstraAirplaneModeConfig.bluetoothWasActive)
            AstraSwitchInerfeces.enableBluetooth(true);

        if (AstraAirplaneModeConfig.wifiWasActive)
            AstraSwitchInerfeces.enableWireless(true);

        if (AstraAirplaneModeConfig.mobileDataWasActive)
            AstraSwitchInerfeces.enableWwan(true);
    }
}
