/*
 * SPDX-FileCopyrightText: 2022 Devin Lin <devin@kde.org>
 * SPDX-License-Identifier: LGPL-2.0-or-later
 */

import QtQuick 2.15
import QtQuick.Layouts 1.15
import QtQuick.Controls 2.15 as QQC2

import org.kde.kirigami 2.19 as Kirigami
import org.kde.kcm 1.3 as KCM
import org.kde.plasma.private.mobileshell 1.0 as MobileShell
import org.kde.kirigamiaddons.labs.mobileform 0.1 as MobileForm

KCM.SimpleKCM {
    id: root

    title: i18n("Shell")

    leftPadding: 0
    rightPadding: 0
    topPadding: Kirigami.Units.gridUnit
    bottomPadding: Kirigami.Units.gridUnit
    
    ColumnLayout {
        spacing: 0
        width: root.width
        
        MobileForm.FormCard {
            Layout.fillWidth: true
            
            contentItem: ColumnLayout {
                spacing: 0
                
                MobileForm.FormCardHeader {
                    title: i18nd("kcm_mobileshell", "General")
                }
                
                MobileForm.FormSwitchDelegate {
                    id: animationsSwitch
                    text: i18nd("kcm_mobileshell", "Animations")
                    description: i18nd("kcm_mobileshell", "If this is off, animations will be reduced as much as possible.")
                    checked: MobileShell.MobileShellSettings.animationsEnabled
                    onCheckedChanged: {
                        if (checked != MobileShell.MobileShellSettings.animationsEnabled) {
                            MobileShell.MobileShellSettings.animationsEnabled = checked;
                        }
                    }
                }
            }
        }
        
        MobileForm.FormCard {
            Layout.fillWidth: true
            Layout.topMargin: Kirigami.Units.largeSpacing
            
            contentItem: ColumnLayout {
                spacing: 0
                
                MobileForm.FormCardHeader {
                    title: i18nd("kcm_mobileshell", "Navigation Panel")
                }
                
                MobileForm.FormSwitchDelegate {
                    id: gestureDelegate
                    text: i18nd("kcm_mobileshell", "Gesture-only Mode")
                    description: i18nd("kcm_mobileshell", "Whether to hide the navigation panel.")
                    checked: !MobileShell.MobileShellSettings.navigationPanelEnabled
                    onCheckedChanged: {
                        if (checked != !MobileShell.MobileShellSettings.navigationPanelEnabled) {
                            MobileShell.MobileShellSettings.navigationPanelEnabled = !checked;
                        }
                    }
                }
            }
        }
        
        MobileForm.FormCard {
            Layout.fillWidth: true
            Layout.topMargin: Kirigami.Units.largeSpacing
            
            contentItem: ColumnLayout {
                spacing: 0
                
                MobileForm.FormCardHeader {
                    title: i18nd("kcm_mobileshell", "Task Switcher")
                }
                
                MobileForm.FormSwitchDelegate {
                    text: i18nd("kcm_mobileshell", "Show Application Previews")
                    description: i18nd("kcm_mobileshell", "Turning this off may help improve performance.")
                    checked: MobileShell.MobileShellSettings.taskSwitcherPreviewsEnabled
                    onCheckedChanged: {
                        if (checked != MobileShell.MobileShellSettings.taskSwitcherPreviewsEnabled) {
                            MobileShell.MobileShellSettings.taskSwitcherPreviewsEnabled = checked;
                        }
                    }
                }
            }
        }
        
        MobileForm.FormCard {
            Layout.fillWidth: true
            Layout.topMargin: Kirigami.Units.largeSpacing
            
            contentItem: ColumnLayout {
                id: parentCol
                spacing: 0
                
                MobileForm.FormCardHeader {
                    title: i18nd("kcm_mobileshell", "Action Drawer")
                }
                
                MobileForm.FormButtonDelegate {
                    id: quickSettingsButton
                    text: i18nd("kcm_mobileshell", "Quick Settings")
                    onClicked: kcm.push("QuickSettingsForm.qml")
                }

                MobileForm.FormDelegateSeparator { above: quickSettingsButton; below: rotationButtonsSwitch }

                MobileForm.FormSwitchDelegate {
                    id: rotationButtonsSwitch
                    text: i18nd("kcm_mobileshell", "Enable screen rotate buttons")
                    description: i18nd("kcm_mobileshell", "If your device doesn't support auto-rotating")
                    checked: MobileShell.MobileShellSettings.showRotationButtons
                    onClicked: MobileShell.MobileShellSettings.showRotationButtons = checked;
                }

                MobileForm.FormDelegateSeparator { above: rotationButtonsSwitch; below: pinnedViewSwitch }

                MobileForm.FormSwitchDelegate {
                    id: pinnedViewSwitch
                    text: i18nd("kcm_mobileshell", "Skip minimized panel view")
                    description: i18nd("kcm_mobileshell", "Enable to skip minimized panel view")
                    checked: MobileShell.MobileShellSettings.actionDrawerTopRightMode === MobileShell.MobileShellSettings.Expanded
                    onClicked: {
                        var mode = checked ? MobileShell.MobileShellSettings.Expanded : MobileShell.MobileShellSettings.Pinned;
                        MobileShell.MobileShellSettings.actionDrawerTopRightMode = mode;
                        MobileShell.MobileShellSettings.actionDrawerTopLeftMode = mode;
                    }
                }

                MobileForm.FormDelegateSeparator { above: pinnedViewSwitch; below: volumeSliderSwitch }

                MobileForm.FormSwitchDelegate {
                    id: volumeSliderSwitch
                    text: i18nd("kcm_mobileshell", "Show volume slider")
                    description: i18nd("kcm_mobileshell", "Turn on to show the volume switcher slider in the top bar")
                    checked: MobileShell.MobileShellSettings.showVolumeSlider
                    onClicked: MobileShell.MobileShellSettings.showVolumeSlider = checked
                }
            }
        }
    }
}
