/*
    SPDX-FileCopyrightText: 2014 Marco Martin <mart@kde.org>

    SPDX-License-Identifier: GPL-2.0-or-later
*/

import QtQuick 2.5
import QtQuick.Window 2.15
import org.kde.plasma.core 2.0 as PlasmaCore

Rectangle {
    id: root
    color: "#2A272B"

    property int stage

    onStageChanged: {
        if (stage == 2) {
            introAnimation.running = true;
        }
    }

    Item {
        id: content
        anchors.fill: parent
        opacity: 0

        Image {
            source: "images/ellipse.svg"
            anchors.fill: parent

            SequentialAnimation on opacity {
                running: true
                loops: Animation.Infinite

                NumberAnimation { from: 0.1; to: 1; duration: 1500; easing.type: Easing.OutQuad; }
                NumberAnimation { from: 1; to: 0.1; duration: 1500; easing.type: Easing.InQuad; }
            }
        }

        Image {
            id: logo
            property real size: PlasmaCore.Units.gridUnit * 8
            anchors.centerIn: parent

            source: "images/star.svgz"

            SequentialAnimation on rotation {
                loops: Animation.Infinite
                running: true

                NumberAnimation { from: 0; to: 360; duration: 2000; }
            }
        }
    }

    OpacityAnimator {
        id: introAnimation
        running: false
        target: content
        from: 0
        to: 1
        duration: PlasmaCore.Units.veryLongDuration * 2
        easing.type: Easing.InOutQuad
    }
}
