/*
 *  SPDX-FileCopyrightText: 2021 Devin Lin <devin@kde.org>
 *
 *  SPDX-License-Identifier: LGPL-2.0-or-later
 */

import QtQuick 2.12
import QtQuick.Layouts 1.1

import org.kde.plasma.core 2.0 as PlasmaCore
import org.kde.plasma.components 3.0 as PlasmaComponents
import org.kde.plasma.extras 2.0 as PlasmaExtra

PlasmaCore.ColorScope {
    id: root
    
    signal switchToListRequested()
    signal switchToGridRequested()
    
    signal switchToAllRequested()
    signal switchToMobileRequested()
    signal switchToWaydroidRequested()

    property bool hideMobileButton
    property bool hideWaydroidButton
    property int selectedButton

    colorGroup: PlasmaCore.Theme.ComplementaryColorGroup
    
    // HACK: Here only to steal inputs the would normally be delivered to home
    MouseArea {
        anchors.fill: parent
    }
    
    RowLayout {
        anchors.topMargin: PlasmaCore.Units.smallSpacing
        anchors.leftMargin: PlasmaCore.Units.largeSpacing
        anchors.rightMargin: PlasmaCore.Units.largeSpacing
        anchors.fill: parent
        spacing: PlasmaCore.Units.smallSpacing
        
        PlasmaExtra.Heading {
            id: heading
            color: "white"
            level: 1
            font.weight: Font.Medium

            PlasmaComponents.ToolButton {
                id: mobButton
                text: i18nd("plasma_applet_org.kde.phone.homescreen", "Mobile")
                visible: root.hideMobileButton

                font.underline: root.selectedButton === AbstractAppDrawer.AppListTypes.Mobile

                onClicked: root.switchToMobileRequested()
            }

            PlasmaComponents.ToolButton {
                id: allButton
                text: i18nd("plasma_applet_org.kde.phone.homescreen", "All (not adapted)")
                anchors.left: (!root.hideMobileButton) ? heading.left : mobButton.right
                anchors.leftMargin: (!root.hideMobileButton) ? 0 : PlasmaCore.Units.gridUnit

                font.underline: root.selectedButton === AbstractAppDrawer.AppListTypes.All

                onClicked: root.switchToAllRequested()
            }

            PlasmaComponents.ToolButton {
                id: waydroidButton
                text: i18nd("plasma_applet_org.kde.phone.homescreen", "Waydroid")
                anchors.left: allButton.right
                anchors.leftMargin: PlasmaCore.Units.gridUnit
                visible: root.hideWaydroidButton

                font.underline: root.selectedButton === AbstractAppDrawer.AppListTypes.Waydroid

                onClicked: root.switchToWaydroidRequested()
            }
        }
        Item { Layout.fillWidth: true }
        PlasmaComponents.ToolButton {
            icon.name: "view-list-symbolic"
            implicitWidth: Math.round(PlasmaCore.Units.gridUnit * 2.1)
            implicitHeight: Math.round(PlasmaCore.Units.gridUnit * 2.1)
            onClicked: root.switchToListRequested()
        }
        PlasmaComponents.ToolButton {
            icon.name: "view-grid-symbolic"
            implicitWidth: Math.round(PlasmaCore.Units.gridUnit * 2.1)
            implicitHeight: Math.round(PlasmaCore.Units.gridUnit * 2.1)
            onClicked: root.switchToGridRequested()
        }
    }
}
