/*
 * SPDX-FileCopyrightText: 2021 Aleix Pol Gonzalez <aleixpol@kde.org>
 * SPDX-FileCopyrightText: 2022 Devin Lin <devin@kde.org>
 * SPDX-License-Identifier: GPL-2.0-or-later
 */

import org.kde.plasma.private.mobileshell 1.0 as MobileShell
import org.kde.plasma.core 2.0 as PlasmaCore
import org.kde.plasma.workspace.keyboardlayout 1.0 as Keyboards

import ru.astralinux.plasma.private.kiosk 1.0

MobileShell.QuickSetting {
    text: i18nd("plasma_org.kde.plasma.quicksetting.keyboardtoggle", "Virtual Keyboard")
    icon: "input-keyboard-virtual"
    status: Kiosk.enable ? "Not Available" : (enabled ? i18nd("plasma_org.kde.plasma.quicksetting.keyboardtoggle", "On") : 
                      (Keyboards.KWinVirtualKeyboard.available ? i18nd("plasma_org.kde.plasma.quicksetting.keyboardtoggle", "Off") : i18nd("plasma_org.kde.plasma.quicksetting.keyboardtoggle", "Tap to open settings")))
    enabled: Keyboards.KWinVirtualKeyboard.enabled && Keyboards.KWinVirtualKeyboard.available
    settingsCommand: "plasma-settings -m kcm_mobile_onscreenkeyboard"
    
    function toggle() {
        if (!Keyboards.KWinVirtualKeyboard.available) {
            // select a keyboard in the settings (none is likely set)
            MobileShell.ShellUtil.executeCommand("plasma-settings -m kcm_mobile_onscreenkeyboard");
        } else {
            Keyboards.KWinVirtualKeyboard.enabled = !enabled;
        }
    }
}


