// SPDX-FileCopyrightText: 2022 Devin Lin <devin@kde.org>
// SPDX-License-Identifier: LGPL-2.0-or-later

import QtQuick 2.15
import QtQuick.Window 2.15

import org.kde.plasma.private.mobileshell 1.0 as MobileShell
import org.kde.plasma.private.mobileshell.state 1.0 as MobileShellState
import org.kde.pipewire.record 0.1 as PWRec
import org.kde.taskmanager 0.1 as TaskManager
import org.kde.plasma.quicksetting.record 1.0
import org.kde.plasma.quicksetting.screenrotation 1.0

import ru.astralinux.plasma.private.kiosk 1.0

MobileShell.QuickSetting {
    id: root

    property bool prevRotationState: ScreenRotationUtil.available && ScreenRotationUtil.screenRotationEnabled

    text: switch (record.state) {
        case PWRec.PipeWireRecord.Idle:
            return i18nd("plasma_org.kde.plasma.quicksetting.record", "Record Screen")
        case PWRec.PipeWireRecord.Recording:
            return i18nd("plasma_org.kde.plasma.quicksetting.record", "Recording…")
        case PWRec.PipeWireRecord.Rendering:
            i18nd("plasma_org.kde.plasma.quicksetting.record", "Writing…")
    }
    status: {
        if (Kiosk.enable)
            return "Not Available";

        switch(record.state) {
        case PWRec.PipeWireRecord.Idle:
            return i18nd("plasma_org.kde.plasma.quicksetting.record", "Tap to start recording")
        case PWRec.PipeWireRecord.Recording:
            return i18nd("plasma_org.kde.plasma.quicksetting.record", "Screen is being captured…")
        case PWRec.PipeWireRecord.Rendering:
            return i18nd("plasma_org.kde.plasma.quicksetting.record", "Please wait…")
        }
    }
    icon: "media-record"
    enabled: false

    function toggle() {
        if(record.state == PWRec.PipeWireRecord.Rendering)
            return; // don't do anything until the rendering is complete

        if (!record.active) {
            root.prevRotationState = ScreenRotationUtil.screenRotationEnabled;
            ScreenRotationUtil.screenRotationEnabled = false;
            record.output = RecordUtil.videoLocation("screen-recording.mp4");
        } else {
            ScreenRotationUtil.screenRotationEnabled = root.prevRotationState;
            RecordUtil.showNotification(i18nd("plasma_org.kde.plasma.quicksetting.record", "New Screen Recording"), i18nd("plasma_org.kde.plasma.quicksetting.record", "New Screen Recording saved in %1", record.output), record.output);
        }
        
        enabled = !enabled
        MobileShellState.Shell.closeActionDrawer();
    }

    PWRec.PipeWireRecord {
        id: record
        nodeId: waylandItem.nodeId
        active: root.enabled
        encoder: "libx264"
    }
    TaskManager.ScreencastingRequest {
        id: waylandItem
        outputName: Screen.name
    }
}
