/*
 *   SPDX-FileCopyrightText: 2023 Boris Pek <bpek@astralinux.ru>
 *
 *   SPDX-License-Identifier: LGPL-2.0-or-later
 */

import QtQuick 2.2
import QtQuick.Controls 2.5 as QQC2
import QtQuick.Layouts 1.4
import QtQuick.Window 2.1

import org.kde.kirigami 2.6 as Kirigami
import org.kde.kquickcontrolsaddons 2.0 as KQuickControlsAddons
import org.kde.plasma.core 2.0 as PlasmaCore
import org.kde.plasma.components 3.0 as PC3
import org.kde.plasma.extras 2.0 as PlasmaExtras
import org.kde.plasma.private.mobileshell.shell 2.0

PC3.Drawer {
    id: root

    property QtObject containment
    property Item containmentInterface
    readonly property bool horizontal: containmentInterface.width <= containmentInterface.height
    readonly property int delegateSize: PlasmaCore.Units.gridUnit * 8

    property int topPanelHeight
    property int bottomPanelHeight
    property int leftPanelWidth
    property int rightPanelWidth

    visible: true

    width: horizontal ? containmentInterface.screenGeometry.width : implicitWidth + leftPadding
    height: horizontal ? implicitHeight + bottomPadding : containmentInterface.screenGeometry.height
    edge: horizontal ? Qt.BottomEdge : Qt.LeftEdge

    leftPadding: horizontal ? 0 : PlasmaCore.Units.smallSpacing
    rightPadding: 0
    topPadding: horizontal ? PlasmaCore.Units.smallSpacing : containmentInterface.availableScreenRect.y
    bottomPadding: containmentInterface.screenGeometry.height - containmentInterface.availableScreenRect.height - containmentInterface.availableScreenRect.y

    implicitHeight: layout.implicitHeight
    implicitWidth: layout.implicitWidth

    contentItem: Item {
        implicitHeight: layout.implicitHeight
        implicitWidth: layout.implicitWidth
        clip: false

        GridLayout {
            id: layout
            anchors {
                right: parent.right
                left: root.horizontal ? parent.left : undefined
                top: parent.top
                bottom: root.horizontal ? undefined : parent.bottom
            }
            columns: 1
            rows: 2
            rowSpacing: PlasmaCore.Units.smallSpacing

            Item {
                id: relativeSizeView
                clip: false
                implicitHeight: relativeSizeLayout.implicitHeight
                implicitWidth: relativeSizeLayout.implicitWidth

                Layout.fillWidth: root.horizontal
                Layout.column: 0
                Layout.row: root.horizontal ? 1 : 0

                RowLayout {
                    id: relativeSizeLayout
                    spacing: 0
                    implicitHeight: relativeSizeComboBox.height + PlasmaCore.Units.smallSpacing * 2

                    QQC2.ComboBox {
                        id: relativeSizeComboBox

                        Layout.margins: PlasmaCore.Units.smallSpacing
                        Layout.preferredWidth: delegateSize + PlasmaCore.Units.gridUnit - Layout.margins * 2

                        textRole: "label"
                        model: widgetsExplorer.filter.availableSizes
                        currentIndex: 0

                        onModelChanged: {
                            currentIndex = widgetsExplorer.filter.defaultSizeIndex
                        }

                        onCurrentTextChanged: {
                            widgetsExplorer.filter.setCurrentSize(currentText)
                            root.containmentInterface.state = currentText;
                        }
                    }
                }
            }

            PC3.ScrollView {
                id: view
                clip: false
                implicitWidth: delegateSize + PlasmaCore.Units.gridUnit
                implicitHeight: delegateSize + PlasmaCore.Units.gridUnit * 3 + root.topPanelHeight

                Layout.fillWidth: root.horizontal
                Layout.fillHeight: !root.horizontal
                Layout.column: 0
                Layout.row: root.horizontal ? 0 : 1

                ListView {
                    id: appletsList
                    clip: false
                    orientation: root.horizontal ? ListView.Horizontal : ListView.Vertical
                    model: widgetsExplorer.widgetsModel
                    delegate: AppletDelegate {}
                }
            }
        }
    }

    WidgetsExplorer {
        id: widgetsExplorer
        containment: root.containment
        onShouldClose: root.close()
    }
}
